@@ -100,7 +100,7 @@ def __updata_driver(my_version, use_os):
     从网页中下载driver文件并保存在当前目录下
     :param my_version: 当前浏览器的版本
     :param use_os: 当前使用的系统
-    :return:
+    :return: 下载的driver版本，或者为None
     """
     try:
         if use_os == 'linux':
@@ -138,6 +138,7 @@ def __unzip_file(zip_file):
     :param upzippath: 需要保存的路径
     :return:
     """
+
     print('\033[1;50;32m正在解压下载的压缩文件\033[0m')
     file = zipfile.ZipFile(zip_file)
     for name in file.namelist():
@@ -218,10 +219,14 @@ def __deleta_files():
     for exe in files:
         Path(exe).unlink(missing_ok=True)
 
-
-
+# 修改drvier为自行传入的方式
 def driver(*args, **kwargs):
     try:
+        # 如果能直接获取到drvier则直接进行返回
+        # 添加option配置，使其不会因函数运行结束而结束driver程序
+        # 阻止关闭会出现日志报错行为，使用selenium的option选项剔除
+        option.add_experimental_option("detach", True)
+        option.add_experimental_option("excludeSwitches", ['enable-automation', 'enable-logging'])
         dr = webdriver.Chrome(*args, **kwargs, options=option)
         print('='*36)
         print(f'\033[1;50;32m{"*"*10} driver已正常启动 {"*"*10}\033[0m')
@@ -237,7 +242,6 @@ def driver(*args, **kwargs):
                 chrome_version = erro_info.split(' ')[4]
                 print(f'\033[1;50;33m当前浏览器版本：<{chrome_version}>\033[0m')
                 if chrome_version:
-                    # if pypath == '':
                     if option.os_ == '':
                         __get_system()
                     else:
@@ -271,3 +275,4 @@ def driver(*args, **kwargs):
         else:
             print(f'\033[1;50;31m{e}\033[0m')
             print('\033[1;50;31m启用driver报错，可能是options配置出现问题、driver文件不存在、方法调用错误\033[0m')
+
